"""

Configs migration



Generation datetime: 2021-08-10 10:01:41.364584

"""

from typing import List

from configs_core.migration.db_migrate_helper import DatabaseMigrationHelper, LimitationToModify

mh: DatabaseMigrationHelper

REVISION = "5b22225f"

DOWN_REVISION = "780ab891"


def upgradeFaceDetV3Setting(setting: dict) -> dict:
    """Upgrade FaceDetV3 setting."""
    setting["redetect_score_threshold"] = 0.3
    return setting


def downgradeFaceDetV3Setting(setting: dict) -> dict:
    """Downgrade FaceDetV3 setting."""
    setting["redetect_score_threshold"] = 0.357
    return setting


limitationsToModify: List[LimitationToModify] = [
    LimitationToModify(
        limitationName="FACE_DETECTOR_V3",
        oldDefaultValue={
            "max_face_size": 640,
            "min_face_size": 50,
            "redetect_tensor_size": 80,
            "redetect_face_target_size": 45,
            "redetect_score_threshold": 0.357,
            "score_threshold": 0.89,
        },
        newDefaultValue={
            "max_face_size": 640,
            "min_face_size": 50,
            "redetect_tensor_size": 80,
            "redetect_face_target_size": 45,
            "redetect_score_threshold": 0.3,
            "score_threshold": 0.89,
        },
        settingUpgradeFunction=upgradeFaceDetV3Setting,
        settingDowngradeFunction=downgradeFaceDetV3Setting,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-handlers"],
        newServices=["luna-handlers"],
    ),
]


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to modify

    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify

    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)
