"""
Configs migration

Generation datetime: 2023-11-15 10:40:02.265080
"""

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper

REVISION = "e7490433"
DOWN_REVISION = "9c6b9bbd"


def upgradeFunction(setting: dict):
    if setting.get("sentinel"):
        setting["sentinel"]["user"] = ""
        setting["sentinel"]["password"] = ""
    setting["user"] = ""
    return setting


def downgradeFunction(setting: dict):
    if setting.get("sentinel"):
        setting["sentinel"].pop("user")
        setting["sentinel"].pop("password")
    setting.pop("user", None)
    return setting


limitationsToModify: list[LimitationToModify] = [
    LimitationToModify(
        limitationName="REDIS_DB_ADDRESS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "host": {"type": "string"},
                "port": {"type": "integer", "minimum": 1, "maximum": 65535},
                "password": {"type": "string"},
                "channel": {"type": "string"},
                "sentinel": {
                    "description": "Redis sentinels settings",
                    "type": "object",
                    "properties": {
                        "master_name": {"type": "string"},
                        "sentinels": {
                            "type": "array",
                            "items": {
                                "description": "Redis sentinel settings. Host+port",
                                "type": "string",
                                "pattern": "[a-zA-Z0-9.]+:\\d{1,5}",
                                "example": "127.0.0.1:26379",
                            },
                        },
                    },
                    "additionalProperties": False,
                    "required": ["master_name", "sentinels"],
                },
            },
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "host": {"type": "string"},
                "port": {"type": "integer", "minimum": 1, "maximum": 65535},
                "user": {"type": "string"},
                "password": {"type": "string"},
                "channel": {"type": "string"},
                "sentinel": {
                    "description": "Redis sentinels settings",
                    "type": "object",
                    "properties": {
                        "master_name": {"type": "string"},
                        "sentinels": {
                            "type": "array",
                            "items": {
                                "description": "Redis sentinel settings. Host+port",
                                "type": "string",
                                "pattern": "[a-zA-Z0-9.]+:\\d{1,5}",
                                "example": "127.0.0.1:26379",
                            },
                        },
                        "user": {"type": "string"},
                        "password": {"type": "string"},
                    },
                    "additionalProperties": False,
                    "required": ["master_name", "sentinels", "user", "password"],
                },
            },
            "additionalProperties": False,
        },
        oldDefaultValue={
            "host": "127.0.0.1",
            "port": 6379,
            "password": "",
            "channel": "luna-sender",
            "sentinel": {"master_name": "luna_sender_master", "sentinels": []},
        },
        newDefaultValue={
            "host": "127.0.0.1",
            "port": 6379,
            "user": "",
            "password": "",
            "channel": "luna-sender",
            "sentinel": {
                "master_name": "luna_sender_master",
                "sentinels": [],
                "user": "",
                "password": "",
            },
        },
        settingUpgradeFunction=upgradeFunction,
        settingDowngradeFunction=downgradeFunction,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-handlers", "luna-sender"],
        newServices=["luna-handlers", "luna-sender"],
    ),
    LimitationToModify(
        limitationName="LUNA_ATTRIBUTES_DB",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "host": {"type": "string"},
                "port": {"type": "integer", "minimum": 1, "maximum": 65535},
                "password": {"type": "string"},
                "sentinel": {
                    "description": "Redis sentinels settings",
                    "type": "object",
                    "properties": {
                        "master_name": {"type": "string"},
                        "sentinels": {
                            "type": "array",
                            "items": {
                                "description": "Redis sentinel settings. Host+port",
                                "type": "string",
                                "pattern": "[a-zA-Z0-9.]+:\\d{1,5}",
                                "example": "127.0.0.1:26379",
                            },
                        },
                    },
                    "additionalProperties": False,
                    "required": ["master_name", "sentinels"],
                },
                "number": {
                    "type": "integer",
                    "enum": [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14],
                },
            },
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "host": {"type": "string"},
                "port": {"type": "integer", "minimum": 1, "maximum": 65535},
                "user": {"type": "string"},
                "password": {"type": "string"},
                "sentinel": {
                    "description": "Redis sentinels settings",
                    "type": "object",
                    "properties": {
                        "master_name": {"type": "string"},
                        "sentinels": {
                            "type": "array",
                            "items": {
                                "description": "Redis sentinel settings. Host+port",
                                "type": "string",
                                "pattern": "[a-zA-Z0-9.]+:\\d{1,5}",
                                "example": "127.0.0.1:26379",
                            },
                        },
                        "user": {"type": "string"},
                        "password": {"type": "string"},
                    },
                    "additionalProperties": False,
                    "required": ["master_name", "sentinels", "user", "password"],
                },
                "number": {
                    "type": "integer",
                    "enum": [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14],
                },
            },
            "additionalProperties": False,
        },
        oldDefaultValue={
            "host": "127.0.0.1",
            "port": 6379,
            "password": "",
            "sentinel": {"master_name": "luna_attributes", "sentinels": []},
            "number": 0,
        },
        newDefaultValue={
            "host": "127.0.0.1",
            "port": 6379,
            "user": "",
            "password": "",
            "sentinel": {
                "master_name": "luna_attributes",
                "sentinels": [],
                "user": "",
                "password": "",
            },
            "number": 0,
        },
        settingUpgradeFunction=upgradeFunction,
        settingDowngradeFunction=downgradeFunction,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-faces", "luna-matcher-proxy", "luna-python-matcher"],
        newServices=["luna-faces", "luna-matcher-proxy", "luna-python-matcher"],
    ),
    LimitationToModify(
        limitationName="BACKPORT3_EVENTS_DB_ADDRESS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "host": {"type": "string"},
                "port": {"type": "integer", "minimum": 1, "maximum": 65535},
                "password": {"type": "string"},
                "channel": {"type": "string"},
                "sentinel": {
                    "description": "Redis sentinels settings",
                    "type": "object",
                    "properties": {
                        "master_name": {"type": "string"},
                        "sentinels": {
                            "type": "array",
                            "items": {
                                "description": "Redis sentinel settings. Host+port",
                                "type": "string",
                                "pattern": "[a-zA-Z0-9.]+:\\d{1,5}",
                                "example": "127.0.0.1:26379",
                            },
                        },
                    },
                    "additionalProperties": False,
                    "required": ["master_name", "sentinels"],
                },
            },
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "host": {"type": "string"},
                "port": {"type": "integer", "minimum": 1, "maximum": 65535},
                "user": {"type": "string"},
                "password": {"type": "string"},
                "channel": {"type": "string"},
                "sentinel": {
                    "description": "Redis sentinels settings",
                    "type": "object",
                    "properties": {
                        "master_name": {"type": "string"},
                        "sentinels": {
                            "type": "array",
                            "items": {
                                "description": "Redis sentinel settings. Host+port",
                                "type": "string",
                                "pattern": "[a-zA-Z0-9.]+:\\d{1,5}",
                                "example": "127.0.0.1:26379",
                            },
                        },
                        "user": {"type": "string"},
                        "password": {"type": "string"},
                    },
                    "additionalProperties": False,
                    "required": ["master_name", "sentinels", "user", "password"],
                },
            },
            "additionalProperties": False,
        },
        oldDefaultValue={
            "host": "127.0.0.1",
            "port": 6379,
            "password": "",
            "channel": "luna-backport3",
            "sentinel": {"master_name": "luna_backport3_master", "sentinels": []},
        },
        newDefaultValue={
            "host": "127.0.0.1",
            "port": 6379,
            "user": "",
            "password": "",
            "channel": "luna-backport3",
            "sentinel": {
                "master_name": "luna_backport3_master",
                "sentinels": [],
                "user": "",
                "password": "",
            },
        },
        settingUpgradeFunction=upgradeFunction,
        settingDowngradeFunction=downgradeFunction,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-backport3"],
        newServices=["luna-backport3"],
    ),
    LimitationToModify(
        limitationName="TASKS_REDIS_DB_ADDRESS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "host": {"type": "string"},
                "port": {"type": "integer", "minimum": 1, "maximum": 65535},
                "password": {"type": "string"},
                "sentinel": {
                    "description": "Redis sentinels settings",
                    "type": "object",
                    "properties": {
                        "master_name": {"type": "string"},
                        "sentinels": {
                            "type": "array",
                            "items": {
                                "description": "Redis sentinel settings. Host+port",
                                "type": "string",
                                "pattern": "[a-zA-Z0-9.]+:\\d{1,5}",
                                "example": "127.0.0.1:26379",
                            },
                        },
                    },
                    "additionalProperties": False,
                    "required": ["master_name", "sentinels"],
                },
                "number": {
                    "type": "integer",
                    "enum": [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14],
                },
            },
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "host": {"type": "string"},
                "port": {"type": "integer", "minimum": 1, "maximum": 65535},
                "user": {"type": "string"},
                "password": {"type": "string"},
                "sentinel": {
                    "description": "Redis sentinels settings",
                    "type": "object",
                    "properties": {
                        "master_name": {"type": "string"},
                        "sentinels": {
                            "type": "array",
                            "items": {
                                "description": "Redis sentinel settings. Host+port",
                                "type": "string",
                                "pattern": "[a-zA-Z0-9.]+:\\d{1,5}",
                                "example": "127.0.0.1:26379",
                            },
                        },
                        "user": {"type": "string"},
                        "password": {"type": "string"},
                    },
                    "additionalProperties": False,
                    "required": ["master_name", "sentinels", "user", "password"],
                },
                "number": {
                    "type": "integer",
                    "enum": [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14],
                },
            },
            "additionalProperties": False,
        },
        oldDefaultValue={
            "host": "127.0.0.1",
            "port": 6379,
            "password": "",
            "sentinel": {"master_name": "luna_tasks", "sentinels": []},
            "number": 0,
        },
        newDefaultValue={
            "host": "127.0.0.1",
            "port": 6379,
            "user": "",
            "password": "",
            "sentinel": {
                "master_name": "luna_tasks",
                "sentinels": [],
                "user": "",
                "password": "",
            },
            "number": 0,
        },
        settingUpgradeFunction=upgradeFunction,
        settingDowngradeFunction=downgradeFunction,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-tasks"],
        newServices=["luna-tasks"],
    ),
]

externalLimitationsToModify: list[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)
