"""
Configs migration

Generation datetime: 2024-11-15 06:37:00.080963
"""

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper

REVISION = "99bc117b"
DOWN_REVISION = "fdf57abf"
NEW_LIMIT = 100000000
OLD_LIMIT = 100000


def upgradeFunction(setting):
    if setting["cross_match"]["general_limit"] == OLD_LIMIT:
        setting["cross_match"]["general_limit"] = NEW_LIMIT
    return setting


def downgradeFunction(setting):
    if setting["cross_match"]["general_limit"] == NEW_LIMIT:
        setting["cross_match"]["general_limit"] = OLD_LIMIT
    return setting


limitationsToModify: list[LimitationToModify] = [
    LimitationToModify(
        limitationName="PLATFORM_LIMITS",
        oldDefaultValue={
            "match": {
                "array_filter_limit": 1000,
                "reference_limit": 30,
                "candidate_limit": 30,
                "result_candidate_limit": 100,
            },
            "cross_match": {
                "short_array_filter_limit": 1000,
                "array_filter_limit": 20000,
                "result_candidate_limit": 20000,
                "general_limit": 100000,
            },
        },
        newDefaultValue={
            "match": {
                "array_filter_limit": 1000,
                "reference_limit": 30,
                "candidate_limit": 30,
                "result_candidate_limit": 100,
            },
            "cross_match": {
                "short_array_filter_limit": 1000,
                "array_filter_limit": 20000,
                "result_candidate_limit": 20000,
                "general_limit": 100000000,
            },
        },
        settingUpgradeFunction=upgradeFunction,
        settingDowngradeFunction=downgradeFunction,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-lambda-tasks-unit",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-tasks",
        ],
        newServices=[
            "luna-lambda-tasks-unit",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-tasks",
        ],
    ),
]

externalLimitationsToModify: list[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)
